Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client encapsulates and provides logic for querying DNS servers over QUIC. The client should be thread-safe. The client reuses single QUIC connection to the server, while creating multiple parallel QUIC streams.
type Option ¶
type Option interface {
// contains filtered or unexported methods
}
Option represents configuration options for doq.Client.
func WithConnectTimeout ¶
WithConnectTimeout is a configuration option that sets connect timeout for the doq.Client.
func WithReadTimeout ¶
WithReadTimeout is a configuration option that sets read timeout for the doq.Client.
func WithTLSConfig ¶
WithTLSConfig is a configuration option that sets TLS configuration for the doq.Client.
func WithWriteTimeout ¶
WithWriteTimeout is a configuration option that sets write timeout for the doq.Client.
Click to show internal directories.
Click to hide internal directories.